# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl Chandra-Time.t'

#########################

# change 'tests => 1' to 'tests => last_test_to_print';

use Test::More tests => 13;
BEGIN { use_ok('Chandra::Time') };

#########################

# Insert your test code below, the Test::More module is use()ed here so read
# its man page ( perldoc Test::More ) for help writing this test script.

$t = Chandra::Time->new('1998-12-14T05:18:56.816');
ok($t->secs() eq '29999936.816000000', "SECS");
ok($t->unix() eq '913612673.632', "UNIX");
ok($t->date() eq '1998:348:05:17:53.632', "DATE");
ok($t->fits() eq '1998-12-14T05:18:56.816', "FITS");

$t = Chandra::Time->new('2451161.5', {format => 'jd'});
ok($t->secs() eq '29980863.184000000'              , "SECS");
ok($t->caldate() eq '1998Dec14 at 00:00:00.000'    , "CALDATE");
ok($t->numday() =~ /^347:0:1:3.184000/          , "NUMDAY");
ok($t->fits(2500000.1) eq '2132-08-30T14:25:06.184', "FITS");

$time_caldate_tai = Chandra::Time::convert(51160.9996275,
                                            { fmt_in => 'mjd',
                                              sys_in => 'tt',
                                              fmt_out => 'caldate',
                                              sys_out => 'tai',
                                            }
                                           );
ok($time_caldate_tai eq '1998Dec13 at 23:58:55.632', "Convert");

$t = Chandra::Time->new(313996801.0);
ok(abs($t->secs - 313996801.0) < 0.001, "Convert secs");
ok($t->fits() eq '2007-12-14T05:20:01.000');

eval { $parse = $t->parse('1999:012:01:02:03.45'); };
if ($@) {
    diag("parse() method not available because POSIX::strptime not found");
    ok(1);
} else {

  # various platforms return slightly different results because
  # of different OS strptime implementations

    my %exp = (
	       dom   => 12,
	       dow   =>  2,
	       doy   => 12,
	       hour  =>  1,
	       min   =>  2,
	       month =>  1,
	       sec   => 3.450,
	       year  => 1999,
	      );


    if ( $^O eq 'solaris' )
    {
	delete $exp{dow};
    }

    elsif ( $^O eq 'darwin' )
    {
	delete @exp{ qw[ month dom dow ] };
    }

    ok( 0 == grep { $exp{$_} != $parse->{$_} } keys %exp );
}
